summaryrefslogtreecommitdiffstats
path: root/asmrun/roots.c
diff options
context:
space:
mode:
authorDamien Doligez <damien.doligez-inria.fr>2002-01-18 15:13:26 +0000
committerDamien Doligez <damien.doligez-inria.fr>2002-01-18 15:13:26 +0000
commit09a8c6bc78f4a84c99b68baef2a1dfb10b8c4a4e (patch)
tree5af49766e2f79faac1b5cd24b6fe7e3247ed82dc /asmrun/roots.c
parente0c8e458d294b4d6bfeafcaba75ebede3dc22b5a (diff)
configure: suppression "smart preprocessing" pour MacOS X
asmrun/roots.c, byterun/alloc.c, byterun/gc_ctrl.c, byterun/minor_gc.c, byterun/minor_gc.h, byterun/roots.c, byterun/startup.c: derecursivation du GC mineur byterun/config.h, stdlib/gc.mli: compactage active par defaut (300%) otherlibs/unix/select.c: ajout include MacOS X .cvsignore: bricoles git-svn-id: http://caml.inria.fr/svn/ocaml/trunk@4264 f963ae5c-01c2-4b8c-9fe0-0dff7051ff02
Diffstat (limited to 'asmrun/roots.c')
-rw-r--r--asmrun/roots.c15
1 files changed, 8 insertions, 7 deletions
diff --git a/asmrun/roots.c b/asmrun/roots.c
index e818e91ec..a1eb34805 100644
--- a/asmrun/roots.c
+++ b/asmrun/roots.c
@@ -97,7 +97,8 @@ value * caml_gc_regs;
long caml_globals_inited = 0;
static long caml_globals_scanned = 0;
-/* Call [oldify] on (at least) all the roots that point to the minor heap. */
+/* Call [oldify_one] on (at least) all the roots that point to the minor
+ heap. */
void oldify_local_roots (void)
{
char * sp;
@@ -118,7 +119,7 @@ void oldify_local_roots (void)
i++) {
glob = caml_globals[i];
for (j = 0; j < Wosize_val(glob); j++){
- oldify(Field(glob, j), &Field(glob, j));
+ oldify_one (Field(glob, j), &Field(glob, j));
}
}
caml_globals_scanned = caml_globals_inited;
@@ -146,7 +147,7 @@ void oldify_local_roots (void)
} else {
root = (value *)(sp + ofs);
}
- oldify(*root, root);
+ oldify_one (*root, root);
}
/* Move to next frame */
#ifndef Stack_grows_upwards
@@ -178,18 +179,18 @@ void oldify_local_roots (void)
for (i = 0; i < lr->ntables; i++){
for (j = 0; j < lr->nitems; j++){
root = &(lr->tables[i][j]);
- oldify (*root, root);
+ oldify_one (*root, root);
}
}
}
/* Global C roots */
for (gr = caml_global_roots.forward[0]; gr != NULL; gr = gr->forward[0]) {
- oldify(*(gr->root), gr->root);
+ oldify_one (*(gr->root), gr->root);
}
/* Finalised values */
- final_do_young_roots (&oldify);
+ final_do_young_roots (&oldify_one);
/* Hook */
- if (scan_roots_hook != NULL) (*scan_roots_hook)(oldify);
+ if (scan_roots_hook != NULL) (*scan_roots_hook)(oldify_one);
}
/* Call [darken] on all roots */